@@ -107,6 +107,7 @@ class Drawing:
     miterLimit = gstateDelegateMethod()
     linearGradient = gstateDelegateMethod()
     radialGradient = gstateDelegateMethod()
+    shadow = gstateDelegateMethod()
     font = gstateDelegateMethod()
     fontSize = gstateDelegateMethod()
     openTypeFeatures = gstateDelegateMethod()
@@ -131,14 +132,11 @@ class Drawing:
 
         x, y = position
 
-        self._canvas.save()
-        try:
+        with self._savedCanvasState():
             self._canvas.translate(x, y)
             if self._flipCanvas:
                 self._canvas.scale(1, -1)
             self._drawItem(self._canvas.drawTextBlob, blob, 0, 0)
-        finally:
-            self._canvas.restore()
 
     def image(self, imagePath, position, alpha=1.0):
         im = self._getImage(imagePath)
@@ -148,14 +146,11 @@ class Drawing:
         if self._gstate.fillPaint.blendMode != "normal":
             paint.setBlendMode(self._gstate.fillPaint.skPaint.getBlendMode())
         x, y = position
-        self._canvas.save()
-        try:
+        with self._savedCanvasState():
             self._canvas.translate(x, y + im.height())
             if self._flipCanvas:
                 self._canvas.scale(1, -1)
             self._canvas.drawImage(im, 0, 0, paint)
-        finally:
-            self._canvas.restore()
 
     @staticmethod
     @functools.lru_cache(maxsize=32)
@@ -208,6 +203,12 @@ class Drawing:
         self._canvas.restore()
         self._gstate = self._stack.pop()
 
+    @contextlib.contextmanager
+    def _savedCanvasState(self):
+        self._canvas.save()
+        yield
+        self._canvas.restore()
+
     def saveImage(self, fileName, **kwargs):
         if self._document.isDrawing:
             self._document.endPage()
@@ -216,6 +217,17 @@ class Drawing:
     # Helpers
 
     def _drawItem(self, canvasMethod, *items):
+        shadowPaintFill, offset = self._gstate.fillPaint.skPaintShadowAndOffset
+        if shadowPaintFill is not None:
+            shadowPaintStroke, _ = self._gstate.strokePaint.skPaintShadowAndOffset
+            dx, dy = offset
+            with self._savedCanvasState():
+                self._canvas.translate(dx, dy)
+                if self._gstate.fillPaint.somethingToDraw:
+                    canvasMethod(*items, shadowPaintFill)
+                if self._gstate.strokePaint.somethingToDraw:
+                    canvasMethod(*items, shadowPaintStroke)
+
         if self._gstate.fillPaint.somethingToDraw:
             canvasMethod(*items, self._gstate.fillPaint.skPaint)
         if self._gstate.strokePaint.somethingToDraw:
